@@ -75,7 +75,7 @@ class PullRequestComment(github.GithubObject.GithubObject):
         return self._NoneIfNotSet(self._user)
 
     def delete(self):
-        headers, data = self._requester.requestAndCheck(
+        headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
             self.url,
             None,
@@ -87,7 +87,7 @@ class PullRequestComment(github.GithubObject.GithubObject):
         post_parameters = {
             "body": body,
         }
-        headers, data = self._requester.requestAndCheck(
+        headers, data = self._requester.requestJsonAndCheck(
             "PATCH",
             self.url,
             None,
