@@ -43,7 +43,7 @@ class UserKey(github.GithubObject.GithubObject):
         return self._NoneIfNotSet(self._verified)
 
     def delete(self):
-        headers, data = self._requester.requestAndCheck(
+        headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
             self.url,
             None,
@@ -58,7 +58,7 @@ class UserKey(github.GithubObject.GithubObject):
             post_parameters["title"] = title
         if key is not github.GithubObject.NotSet:
             post_parameters["key"] = key
-        headers, data = self._requester.requestAndCheck(
+        headers, data = self._requester.requestJsonAndCheck(
             "PATCH",
             self.url,
             None,
