@@ -14,12 +14,15 @@
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
 import base64
+import sys
 
 import Framework
 
 import github
 import datetime
 
+atLeastPython3 = sys.hexversion >= 0x03000000
+
 
 class ContentFile(Framework.TestCase):
     def setUp(self):
@@ -32,5 +35,8 @@ class ContentFile(Framework.TestCase):
         self.assertEqual(self.file.size, 7531)
         self.assertEqual(self.file.name, "ReadMe.md")
         self.assertEqual(self.file.path, "ReadMe.md")
-        self.assertEqual(len(base64.b64decode(self.file.content)), 7531)
+        if atLeastPython3:
+            self.assertEqual(len(base64.b64decode(bytearray(self.file.content, "utf-8"))), 7531)  # pragma no cover
+        else:
+            self.assertEqual(len(base64.b64decode(self.file.content)), 7531)
         self.assertEqual(self.file.sha, "5628799a7d517a4aaa0c1a7004d07569cd154df0")
