@@ -12,21 +12,3 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
-
-import sys
-
-atLeastPython27 = sys.hexversion >= 0x02070000
-
-if atLeastPython27:
-    import unittest
-else:  # pragma no cover
-    import unittest2 as unittest  # pragma no cover
-
-import AllTests
-
-
-def run():
-    testLoader = unittest.loader.TestLoader()
-    testRunner = unittest.runner.TextTestRunner(verbosity=1)
-    test = testLoader.loadTestsFromModule(AllTests)
-    return testRunner.run(test)
